@@ -1,7 +1,16 @@
-jq(document).ready(function(){
+jQuery(function(){
     // Accordion
     jq("#accordion").accordion({ header: "h3" });
-    // Dialog
+    // Autocomplete
+    jq("#autocomplete").autocomplete({
+        source: ["c++", "java", "php", "coldfusion", "javascript", "asp", "ruby", "python", "c", "scala", "groovy", "haskell", "perl"]
+    });
+    // Button
+    jq("#button").button();
+    jq("#radioset").buttonset();
+    // Tabs
+    jq('#tabs').tabs();
+    // Dialog           
     jq('#dialog').dialog({
         autoOpen: false,
         width: 600,
@@ -19,7 +28,6 @@ jq(document).ready(function(){
         jq('#dialog').dialog('open');
         return false;
     });
-
     // Datepicker
     jq('#datepicker').datepicker({
         inline: true
